@@ -13,9 +13,17 @@
  */
 
 #include "lib/misc/lib.h"
-#include "dmeventd_lvm.h"
+#include "daemons/dmeventd/plugins/lvm2/dmeventd_lvm.h"
 #include "daemons/dmeventd/libdevmapper-event.h"
-#include "device_mapper/vdo/target.h"
+
+/*
+ * Use parser from new device_mapper library.
+ * Although during compilation we can see dm_vdo_status_parse()
+ * in runtime we are linked against systems libdm 'older' library
+ * which does not provide this symbol and plugin fails to load
+ */
+/* coverity[unnecessary_header] used for parsing */
+#include "device_mapper/vdo/status.c"
 
 #include <sys/wait.h>
 #include <stdarg.h>
@@ -70,7 +78,7 @@ static int _run_command(struct dso_state *state)
 	log_verbose("Executing command: %s", state->cmd_str);
 
 	/* TODO:
-	 *   Support parallel run of 'task' and it's waitpid maintainence
+	 *   Support parallel run of 'task' and it's waitpid maintenance
 	 *   ATM we can't handle signaling of  SIGALRM
 	 *   as signalling is not allowed while 'process_event()' is running
 	 */
@@ -219,7 +227,7 @@ void process_event(struct dm_task *dmt,
 	/*
 	 * Trigger action when threshold boundary is exceeded.
 	 * Report 80% threshold warning when it's used above 80%.
-	 * Only 100% is exception as it cannot be surpased so policy
+	 * Only 100% is exception as it cannot be surpassed so policy
 	 * action is called for:  >50%, >55% ... >95%, 100%
 	 */
 	if ((state->percent > WARNING_THRESH) &&
@@ -253,8 +261,7 @@ void process_event(struct dm_task *dmt,
 	} else
 		state->max_fails = 1; /* Reset on success */
 
-	/* FIXME: ATM nothing can be done, drop 0, once it becomes useful */
-	if (0 && needs_policy)
+	if (needs_policy)
 		_use_policy(dmt, state);
 out:
 	if (vdop.status)
@@ -347,7 +354,7 @@ int register_device(const char *device,
 		_init_thread_signals(state);
 	} else if (cmd[0] == 0) {
 		state->name = "volume"; /* What to use with 'others?' */
-	} else/* Unuspported command format */
+	} else/* Unsupported command format */
 		goto inval;
 
 	state->pid = -1;
