@@ -1796,7 +1796,7 @@ static int _mountinfo_parse_line(const char *line, unsigned *maj, unsigned *min,
 }
 
 /*
- * Function to operate on individal mountinfo line,
+ * Function to operate on individual mountinfo line,
  * minor, major and mount target are parsed and unmangled
  */
 int dm_mountinfo_read(dm_mountinfo_line_callback_fn read_fn, void *cb_data)
@@ -1961,7 +1961,7 @@ static int _sysfs_find_kernel_name(uint32_t major, uint32_t minor, char *buf, si
 				    !strcmp(name_dev, "holders") ||
 				    !strcmp(name_dev, "integrity") ||
 				    !strcmp(name_dev, "loop") ||
-				    !strcmp(name_dev, "queueu") ||
+				    !strcmp(name_dev, "queue") ||
 				    !strcmp(name_dev, "md") ||
 				    !strcmp(name_dev, "mq") ||
 				    !strcmp(name_dev, "power") ||
@@ -2416,7 +2416,7 @@ static int _get_cookie_sem(uint32_t cookie, int *semid)
 			break;
 		case EACCES:
 			log_error("No permission to access "
-				  "notificaton semaphore identified "
+				  "notification semaphore identified "
 				  "by cookie value %" PRIu32 " (0x%x)",
 				  cookie, cookie);
 			break;
@@ -2437,20 +2437,20 @@ static int _udev_notify_sem_inc(uint32_t cookie, int semid)
 	int val;
 
 	if (semop(semid, &sb, 1) < 0) {
-		log_error("semid %d: semop failed for cookie 0x%" PRIx32 ": %s",
+		log_error("cookie inc: semid %d: semop failed for cookie 0x%" PRIx32 ": %s",
 			  semid, cookie, strerror(errno));
 		return 0;
 	}
 
  	if ((val = semctl(semid, 0, GETVAL)) < 0) {
-		log_error("semid %d: sem_ctl GETVAL failed for "
+		log_warn("cookie inc: semid %d: sem_ctl GETVAL failed for "
 			  "cookie 0x%" PRIx32 ": %s",
 			  semid, cookie, strerror(errno));
-		return 0;		
-	}
-
-	log_debug_activation("Udev cookie 0x%" PRIx32 " (semid %d) incremented to %d",
-		  cookie, semid, val);
+		log_debug_activation("Udev cookie 0x%" PRIx32 " (semid %d) incremented.",
+				      cookie, semid);
+	} else
+		log_debug_activation("Udev cookie 0x%" PRIx32 " (semid %d) incremented to %d",
+				     cookie, semid, val);
 
 	return 1;
 }
@@ -2460,23 +2460,21 @@ static int _udev_notify_sem_dec(uint32_t cookie, int semid)
 	struct sembuf sb = {0, -1, IPC_NOWAIT};
 	int val;
 
- 	if ((val = semctl(semid, 0, GETVAL)) < 0) {
-		log_error("semid %d: sem_ctl GETVAL failed for "
-			  "cookie 0x%" PRIx32 ": %s",
-			  semid, cookie, strerror(errno));
-		return 0;
-	}
+ 	if ((val = semctl(semid, 0, GETVAL)) < 0)
+		log_warn("cookie dec: semid %d: sem_ctl GETVAL failed for "
+			 "cookie 0x%" PRIx32 ": %s",
+			 semid, cookie, strerror(errno));
 
 	if (semop(semid, &sb, 1) < 0) {
 		switch (errno) {
 			case EAGAIN:
-				log_error("semid %d: semop failed for cookie "
+				log_error("cookie dec: semid %d: semop failed for cookie "
 					  "0x%" PRIx32 ": "
 					  "incorrect semaphore state",
 					  semid, cookie);
 				break;
 			default:
-				log_error("semid %d: semop failed for cookie "
+				log_error("cookie dec: semid %d: semop failed for cookie "
 					  "0x%" PRIx32 ": %s",
 					  semid, cookie, strerror(errno));
 				break;
@@ -2484,9 +2482,12 @@ static int _udev_notify_sem_dec(uint32_t cookie, int semid)
 		return 0;
 	}
 
-	log_debug_activation("Udev cookie 0x%" PRIx32 " (semid %d) decremented to %d",
-			     cookie, semid, val - 1);
-
+	if (val < 0)
+		log_debug_activation("Udev cookie 0x%" PRIx32 " (semid %d) decremented.",
+				     cookie, semid);
+	else
+		log_debug_activation("Udev cookie 0x%" PRIx32 " (semid %d) decremented to %d",
+				     cookie, semid, val - 1);
 	return 1;
 }
 
@@ -2563,7 +2564,7 @@ static int _udev_notify_sem_create(uint32_t *cookie, int *semid)
 	sem_arg.val = 1;
 
 	if (semctl(gen_semid, 0, SETVAL, sem_arg) < 0) {
-		log_error("semid %d: semctl failed: %s", gen_semid, strerror(errno));
+		log_error("cookie create: semid %d: semctl failed: %s", gen_semid, strerror(errno));
 		/* We have to destroy just created semaphore
 		 * so it won't stay in the system. */
 		(void) _udev_notify_sem_destroy(gen_cookie, gen_semid);
@@ -2571,9 +2572,10 @@ static int _udev_notify_sem_create(uint32_t *cookie, int *semid)
 	}
 
  	if ((val = semctl(gen_semid, 0, GETVAL)) < 0) {
-		log_error("semid %d: sem_ctl GETVAL failed for "
+		log_error("cookie create: semid %d: sem_ctl GETVAL failed for "
 			  "cookie 0x%" PRIx32 ": %s",
 			  gen_semid, gen_cookie, strerror(errno));
+		(void) _udev_notify_sem_destroy(gen_cookie, gen_semid);
 		goto bad;
 	}
 
