@@ -128,7 +128,15 @@ struct vdo_volume_geometry {
 	struct vdo_index_config index_config;
 } __packed;
 
-/* Decoding mostly only some used stucture members */
+struct vdo_volume_geometry_4 {
+	uint32_t release_version;
+	uint64_t nonce;
+	uuid_t uuid;
+	struct vdo_volume_region regions[VDO_VOLUME_REGION_COUNT];
+	struct vdo_index_config index_config;
+} __packed;
+
+/* Decoding mostly only some used structure members */
 
 static void _vdo_decode_version(struct vdo_version_number *v)
 {
@@ -146,13 +154,24 @@ static void _vdo_decode_header(struct vdo_header *h)
 static void _vdo_decode_geometry_region(struct vdo_volume_region *vr)
 {
 	vr->id = le32_to_cpu(vr->id);
-	vr->start_block = le32_to_cpu(vr->start_block);
+	vr->start_block = le64_to_cpu(vr->start_block);
 }
 
 static void _vdo_decode_volume_geometry(struct vdo_volume_geometry *vg)
 {
-	vg->release_version = le64_to_cpu(vg->release_version);
+	vg->release_version = le32_to_cpu(vg->release_version);
 	vg->nonce = le64_to_cpu(vg->nonce);
+	vg->bio_offset = le64_to_cpu(vg->bio_offset);
+	_vdo_decode_geometry_region(&vg->regions[VDO_DATA_REGION]);
+}
+
+static void _vdo_decode_volume_geometry_4(struct vdo_volume_geometry *vg,
+					  struct vdo_volume_geometry_4 *vg_4)
+{
+	vg->release_version = le32_to_cpu(vg_4->release_version);
+	vg->nonce = le64_to_cpu(vg_4->nonce);
+	vg->bio_offset = 0;
+	vg->regions[VDO_DATA_REGION] = vg_4->regions[VDO_DATA_REGION];
 	_vdo_decode_geometry_region(&vg->regions[VDO_DATA_REGION]);
 }
 
@@ -174,9 +193,8 @@ static void _vdo_decode_pvc(struct vdo_component_41_0 *pvc)
 bool dm_vdo_parse_logical_size(const char *vdo_path, uint64_t *logical_blocks)
 {
 	char buffer[4096];
-	int fh, n;
+	int fh;
 	bool r = false;
-	off_t l;
 	struct stat st;
 	uint64_t size;
 	uint64_t regpos;
@@ -184,6 +202,7 @@ bool dm_vdo_parse_logical_size(const char *vdo_path, uint64_t *logical_blocks)
 	struct vdo_header h;
 	struct vdo_version_number vn;
 	struct vdo_volume_geometry vg;
+	struct vdo_volume_geometry_4 vg_4;
 	struct vdo_component_41_0 pvc;
 
 	*logical_blocks = 0;
@@ -207,7 +226,7 @@ bool dm_vdo_parse_logical_size(const char *vdo_path, uint64_t *logical_blocks)
 		size = st.st_size;
 	}
 
-	if ((n = read(fh, buffer, sizeof(buffer))) < 0) {
+	if (read(fh, buffer, sizeof(buffer)) < (MAGIC_NUMBER_SIZE + sizeof(h))) {
 		log_sys_debug("read", vdo_path);
 		goto err;
 	}
@@ -220,32 +239,42 @@ bool dm_vdo_parse_logical_size(const char *vdo_path, uint64_t *logical_blocks)
 	memcpy(&h, buffer + MAGIC_NUMBER_SIZE, sizeof(h));
 	_vdo_decode_header(&h);
 
-	if  (h.version.major_version != 5) {
+	if (h.id != 5) {
+		log_debug_activation("Expected geometry VDO block instead of block %u.", h.id);
+		goto err;
+	}
+
+	switch (h.version.major_version) {
+	case 4:
+		memcpy(&vg_4, buffer + MAGIC_NUMBER_SIZE + sizeof(h), sizeof(vg_4));
+		_vdo_decode_volume_geometry_4(&vg, &vg_4);
+		break;
+	case 5:
+		memcpy(&vg, buffer + MAGIC_NUMBER_SIZE + sizeof(h), sizeof(vg));
+		_vdo_decode_volume_geometry(&vg);
+		break;
+	default:
 		log_debug_activation("Unsupported VDO version %u.%u.", h.version.major_version, h.version.minor_version);
 		goto err;
 	}
 
-	memcpy(&vg, buffer + MAGIC_NUMBER_SIZE + sizeof(h), sizeof(vg));
-	_vdo_decode_volume_geometry(&vg);
-
-	regpos = vg.regions[VDO_DATA_REGION].start_block * 4096;
+	regpos = (vg.regions[VDO_DATA_REGION].start_block - vg.bio_offset) * 4096;
 
 	if ((regpos + sizeof(buffer)) > size) {
 		log_debug_activation("File/Device is shorter and can't provide requested VDO volume region at " FMTu64 " > " FMTu64 ".", regpos, size);
 		goto err;
 	}
 
-	if ((l = lseek(fh, regpos, SEEK_SET)) < 0) {
+	if (lseek(fh, regpos, SEEK_SET) < 0) {
 		log_sys_debug("lseek", vdo_path);
 		goto err;
 	}
 
-	if ((n = read(fh, buffer, sizeof(buffer))) < 0) {
+	if (read(fh, buffer, sizeof(buffer)) < (sizeof(struct vdo_geometry_block) + sizeof(vn))) {
 		log_sys_debug("read", vdo_path);
 		goto err;
 	}
 
-
 	memcpy(&vn, buffer + sizeof(struct vdo_geometry_block), sizeof(vn));
 	_vdo_decode_version(&vn);
 
