@@ -294,7 +294,8 @@ static int _add_alias(struct device *dev, const char *path, enum add_hash hash)
 	size_t path_len = strlen(path);
 
 	if (hash == REHASH)
-		radix_tree_remove(_cache.names, path, path_len);
+		if (!radix_tree_remove(_cache.names, path, path_len))
+			stack;
 
 	/* Is name already there? */
 	dm_list_iterate_items(strl, &dev->aliases)
@@ -305,7 +306,7 @@ static int _add_alias(struct device *dev, const char *path, enum add_hash hash)
 
 	if (!(path = _strdup(path)) ||
 	    !(sl = _zalloc(sizeof(*sl)))) {
-		log_error("Failed to add allias to dev cache.");
+		log_error("Failed to add alias to dev cache.");
 		return 0;
 	}
 
@@ -696,7 +697,8 @@ void dev_cache_failed_path(struct device *dev, const char *path)
 {
 	struct dm_str_list *strl;
 
-	radix_tree_remove(_cache.names, path, strlen(path));
+	if (!radix_tree_remove(_cache.names, path, strlen(path)))
+		stack;
 
 	dm_list_iterate_items(strl, &dev->aliases) {
 		if (!strcmp(strl->str, path)) {
@@ -836,7 +838,7 @@ static size_t _collapse_slashes(char *str)
 
 static int _insert_dir(const char *dir)
 {
-	/* alphanetically! sorted list used by bsearch of
+	/* alphabetically! sorted list used by bsearch of
 	 * /dev subdirectories that should not contain
 	 * any block device, so no reason to scan them. */
 	static const char _no_scan[][12] = {
@@ -1187,7 +1189,8 @@ static void _drop_all_aliases(struct device *dev)
 
 	dm_list_iterate_items_safe(strl, strl2, &dev->aliases) {
 		log_debug("Drop alias for %u:%u %s.", MAJOR(dev->dev), MINOR(dev->dev), strl->str);
-		radix_tree_remove(_cache.names, strl->str, strlen(strl->str));
+		if (!radix_tree_remove(_cache.names, strl->str, strlen(strl->str)))
+			stack;
 		dm_list_del(&strl->list);
 	}
 }
@@ -1281,11 +1284,13 @@ void dm_devs_cache_destroy(void)
 	_cache.use_dm_devs_cache = 0;
 
 	if (_cache.dm_devnos) {
+		log_debug_cache("Destroying DM devno cache.");
 		radix_tree_destroy(_cache.dm_devnos);
 		_cache.dm_devnos = NULL;
 	}
 
 	if (_cache.dm_uuids) {
+		log_debug_cache("Destroying DM uuid cache.");
 		radix_tree_destroy(_cache.dm_uuids);
 		_cache.dm_uuids = NULL;
 	}
@@ -1293,23 +1298,67 @@ void dm_devs_cache_destroy(void)
 	dm_device_list_destroy(&_cache.dm_devs);
 }
 
+/*
+ * Updates cached trees with active DM devices.
+ *
+ * TODO:
+ * For large amount of active devices it might be useful
+ * to update existing trees - especially when there is high
+ * chance the set of active devices is nearly the same).
+ * However its not so trivial, so just make it a TODO.
+ * And do only an easy 1:1 match or full rebuild.
+ */
 int dm_devs_cache_update(void)
 {
-	struct dm_active_device *dm_dev;
+	struct dm_active_device *dm_dev, *dm_dev_new;
 	unsigned devs_features;
 	uint32_t d;
+	struct dm_list *dm_devs_new, *l;
+	int cache_changed = 0;
 
-	dm_devs_cache_destroy();
-
-	if (!get_dm_active_devices(NULL, &_cache.dm_devs, &devs_features))
+	if (!get_dm_active_devices(NULL, &dm_devs_new, &devs_features))
 		return 1;
 
 	if (!(devs_features & DM_DEVICE_LIST_HAS_UUID)) {
 		/* Cache unusable with older kernels without UUIDs in LIST */
-		dm_device_list_destroy(&_cache.dm_devs);
+		dm_device_list_destroy(&dm_devs_new);
 		return 1;
 	}
 
+	if (_cache.dm_devs) {
+		/* Compare existing cached list with a new one.
+		 * When there is any mismatch, just rebuild whole cache */
+		if ((l = dm_list_first(dm_devs_new))) {
+			dm_list_iterate_items(dm_dev, _cache.dm_devs) {
+				dm_dev_new = dm_list_item(l, struct dm_active_device);
+				if ((dm_dev->devno != dm_dev_new->devno) ||
+				    strcmp(dm_dev->uuid, dm_dev_new->uuid)) {
+					log_debug_cache("Mismatching UUID or devno found  %s %u:%u   %s %u:%u.",
+							dm_dev->uuid, MAJOR(dm_dev->devno), MINOR(dm_dev->devno),
+							dm_dev_new->uuid, MAJOR(dm_dev_new->devno), MINOR(dm_dev_new->devno));
+					cache_changed = 1;
+					break;
+				}
+				if (!(l = dm_list_next(dm_devs_new, l))) {
+					if (dm_list_next(_cache.dm_devs, &dm_dev->list))
+						cache_changed = 1; /* old cached list still with entries */
+					break;
+				}
+			}
+		} else
+			cache_changed = 1;
+
+		if (!cache_changed) {
+			log_debug_cache("Preserving DM cache.");
+			dm_device_list_destroy(&dm_devs_new);
+
+			return 1;
+		}
+		dm_devs_cache_destroy();
+	}
+
+	_cache.dm_devs = dm_devs_new;
+
 	/* _cache.dm_devs entries are referenced by radix trees */
 
 	/* TODO: if _cache.dm_devs list is small, then skip the
@@ -1320,6 +1369,7 @@ int dm_devs_cache_update(void)
 		return_0; // FIXME
 	}
 
+	log_debug_cache("Creating DM cache for devno and uuid.");
 	/* Insert every active DM device into radix trees */
 	dm_list_iterate_items(dm_dev, _cache.dm_devs) {
 		d = _shuffle_devno(dm_dev->devno);
@@ -1344,6 +1394,8 @@ void dm_devs_cache_label_invalidate(struct cmd_context *cmd)
 	struct dm_active_device *dm_dev;
 	struct device *dev;
 
+	dm_devs_cache_update();
+
 	dm_list_iterate_items(dm_dev, _cache.dm_devs) {
 		if (dm_dev->uuid &&
 		   strncmp(dm_dev->uuid, UUID_PREFIX, sizeof(UUID_PREFIX) - 1) == 0) {
@@ -1572,7 +1624,8 @@ void dev_cache_verify_aliases(struct device *dev)
 			log_debug("Drop alias for %u:%u invalid path %s %u:%u.",
 				  MAJOR(dev->dev), MINOR(dev->dev), strl->str,
 				  MAJOR(st.st_rdev), MINOR(st.st_rdev));
-			radix_tree_remove(_cache.names, strl->str, strlen(strl->str));
+			if (!radix_tree_remove(_cache.names, strl->str, strlen(strl->str)))
+				stack;
 			dm_list_del(&strl->list);
 		}
 	}
@@ -1606,7 +1659,8 @@ static struct device *_dev_cache_get(struct cmd_context *cmd, const char *name,
 			log_debug("Device path %s is invalid for %u:%u %s.",
 				  name, MAJOR(dev->dev), MINOR(dev->dev), dev_name(dev));
 
-			radix_tree_remove(_cache.names, name, strlen(name));
+			if (!radix_tree_remove(_cache.names, name, strlen(name)))
+				stack;
 
 			_remove_alias(dev, name);
 
@@ -2451,7 +2505,7 @@ int setup_devname_in_dev_cache(struct cmd_context *cmd, const char *devname)
 	}
 
 	if (!S_ISBLK(buf.st_mode)) {
-		log_error("Invaild device type %s.", devname);
+		log_error("Invalid device type %s.", devname);
 		return 0;
 	}
 
