@@ -596,6 +596,7 @@ static int _split_mirror_images(struct logical_volume *lv,
 	struct lv_list *lvl;
 	struct cmd_context *cmd = lv->vg->cmd;
 	char layer_name[NAME_LEN], format[NAME_LEN];
+	const char *lv_name;
 	int act;
 
 	if (!lv_is_mirrored(lv)) {
@@ -662,8 +663,8 @@ static int _split_mirror_images(struct logical_volume *lv,
 		return 0;
 	}
 
-	new_lv->name = dm_pool_strdup(lv->vg->vgmem, split_name);
-	if (!new_lv->name) {
+	if (!(lv_name = dm_pool_strdup(lv->vg->vgmem, split_name)) ||
+	    !lv_set_name(new_lv, lv_name)) {
 		log_error("Unable to rename newly split LV.");
 		return 0;
 	}
@@ -699,7 +700,8 @@ static int _split_mirror_images(struct logical_volume *lv,
 					  display_lvname(new_lv));
 				return 0;
 			}
-			if (!(sub_lv->name = dm_pool_strdup(lv->vg->vgmem, layer_name))) {
+			if (!(lv_name = dm_pool_strdup(lv->vg->vgmem, layer_name)) ||
+			    !lv_set_name(sub_lv, lv_name)) {
 				log_error("Unable to allocate memory.");
 				return 0;
 			}
@@ -780,7 +782,7 @@ static int _split_mirror_images(struct logical_volume *lv,
  * If collapse is non-zero, <removed> is guaranteed to be equal to num_removed.
  *
  * Return values:
- *   Failure (0) means something unexpected has happend and
+ *   Failure (0) means something unexpected has happened and
  *   the caller should abort.
  *   Even if no mirror was removed (e.g. no LV matches to 'removable_pvs'),
  *   returns success (1).
@@ -991,7 +993,11 @@ static int _remove_mirror_images(struct logical_volume *lv,
 
 	/* Mirror with only 1 area is 'in sync'. */
 	if (new_area_count == 1 && is_temporary_mirror_layer(lv)) {
-		detached_log_lv = detach_mirror_log(mirrored_seg);
+		if (!(detached_log_lv = detach_mirror_log(mirrored_seg))) {
+			log_error("Cannot detach mirror log from %s..",
+				  display_lvname(mirrored_seg->lv));
+			return 0;
+		}
 		if (!_init_mirror_log(lv->vg->cmd,
 				      (struct logical_volume*)lv_lock_holder(mirrored_seg->lv),
 				      detached_log_lv,
@@ -1367,11 +1373,12 @@ int fixup_imported_mirrors(struct volume_group *vg)
 {
 	struct lv_list *lvl;
 	struct lv_segment *seg;
+	const struct segment_type *mirror_segtype =
+		get_segtype_from_string(vg->cmd, SEG_TYPE_NAME_MIRROR);
 
 	dm_list_iterate_items(lvl, &vg->lvs) {
 		dm_list_iterate_items(seg, &lvl->lv->segments) {
-			if (seg->segtype !=
-			    get_segtype_from_string(vg->cmd, SEG_TYPE_NAME_MIRROR))
+			if (seg->segtype != mirror_segtype)
 				continue;
 
 			if (seg->log_lv && !add_seg_to_segs_using_this_lv(seg->log_lv, seg))
