@@ -16,6 +16,9 @@ SKIP_WITH_LVMPOLLD=1
 
 . lib/inittest
 
+lvm segtypes 2>/dev/null | grep writecache$ >/dev/null || {
+	skip 'Writecache is not built-in.'
+}
 aux have_cache 1 10 0 || skip
 which mkfs.xfs || skip
 
@@ -25,13 +28,13 @@ mkdir -p "$mount_dir"
 # generate random data
 dd if=/dev/urandom of=pattern1 bs=512K count=1
 
-aux prepare_devs 2 64
+aux prepare_devs 2 310
 
 vgcreate $SHARED $vg "$dev1"
 
 vgextend $vg "$dev2"
 
-lvcreate -n $lv1 -l 8 -an $vg "$dev1"
+lvcreate -n $lv1 -L 300 -an $vg "$dev1"
 
 lvcreate -n $lv2 -l 4 -an $vg "$dev2"
 
