@@ -28,7 +28,7 @@ aux lvmconf "backup/backup = 0"
 # vgcfgbackup correctly stores metadata LVM1 with missing PVs
 
 pvcreate -M1 "${DEVICES[@]}"
-vgcreate $SHARED -M1 -c n "$vg" "${DEVICES[@]}"
+vgcreate $SHARED -M1 "$vg" "${DEVICES[@]}"
 lvcreate -l1 -n $lv1 $vg "$dev1"
 pvremove -ff -y "$dev2"
 not lvcreate -l1 -n $lv1 $vg "$dev3"
